// Luca De Benedictis - Luca Salvatici ### GRAVITY ###
// EXAMPLE 2


clear all
set mem 1000m
set maxvar 20000
set matsize 7000
capture log close
log using "GravityLab-1-IntroToStata.log", replace



* Set working directory (where the data is)
cd "/Users/debene2/Dropbox/2015 - Lectures - Gravity/Stata do and dta files"





*loading the data
*It comes from https://sites.google.com/site/hiegravity/data-sources/CEPII's gravity dataset 
*The same data with a new name is in the folder
use HeadMayerRies2010.dta, replace

*first look at the data
desc 

la var iso_o "ISO3 code of origin (exporter) country"
la var iso_d "ISO3 code of destination (importer) country"


tabulate iso_o
tabulate year

*Descriptive statistics with summarize
summarize flow gdp_o gdp_d distw

generate lflow = ln(flow)
generate lgdp_o = ln(gdp_o)
generate lgdp_d = ln(gdp_d)
generate ldistw = ln(distw)

la var lflow "logarithm of trade flows"
la var lgdp_o "Log GDP_exporter"
la var lgdp_d "Log GDP_importer"
la var ldistw "Log distance"


*Bivariate regressions between gravity variables

*FRANCE in 2006 as a country study
*Distance
twoway (scatter lflow ldistw, mlabel(iso_d)) (lfit lflow ldistw) if (year==2006 & iso_o =="FRA"), title(France in 2006) xtitle (log of distance)
*Distinguishing colonies
twoway (scatter lflow ldistw if col_hist==0, mlabel(iso_d)) (scatter lflow ldistw if col_hist==1, mlabel(iso_d))(lfit lflow ldistw) if (year==2006 & iso_o =="FRA"), title(France in 2006) xtitle (log of distance)legend(label(1 no-colony) label(2 colony))

*GDP of destination country(j)
twoway (scatter lflow lgdp_d, mlabel(iso_d)) (lfit lflow lgdp_d) if (year==2006 & iso_o =="FRA"), title(France in 2006) xtitle (log of GDPj)


*******************************************************
////  Exercise 1: Do the same for your own country ////
*******************************************************


*Distance
twoway (scatter lflow ldistw, mlabel(iso_d)) (lfit lflow ldistw) if (year==2006 & iso_o =="ZWE"), title(Zimbabwe in 2006) xtitle (log of distance)






*Simple Linear Regression
regress lflow lgdp_o lgdp_d ldistw, robust
*Generate predicted values of the dependent variable
predict plflow


*correlation between predicted and actual flows
corr lflow plflow

 
*A useful way to check if the model is over/under predicting the data

line lflow year if (iso_d=="ITA" & iso_o =="FRA"),|| line plflow year if (iso_d=="ITA" & iso_o =="FRA")

line lflow year if (iso_d=="IND" & iso_o =="PAK"),|| line plflow year if (iso_d=="IND" & iso_o =="PAK")

***************************************************
////  Exercise 2: Find an other historical case ////
***************************************************

line lflow year if (iso_d=="ITA" & iso_o =="ROM"),|| line plflow year if (iso_d=="ITA" & iso_o =="ROM")



***************************************************
////  Exercise 3: Build a fake variable ////
***************************************************


egen fake = std(ln((year+sever+indepdate)*5))

*Simple Linear Regression
regress lflow lgdp_o lgdp_d ldistw fake, robust
regress lflow lgdp_o lgdp_d ldistw year, robust

regress lflow lgdp_o lgdp_d ldistw, robust



