// Luca De Benedictis - Luca Salvatici ### GRAVITY ###
// EXAMPLE 1


clear all
set mem 1000m
set maxvar 20000
set matsize 7000
capture log close
log using "GravityLab-1-IntroToStata.log", replace




* Set working directory (where the data is)
cd "/Users/debene2/Dropbox/2015 - Lectures - Gravity/Stata do and dta files"





*loading the data
use openness_12.dta, replace

*first look at the data
desc 

*Descriptive statistics with summarize
summarize openc gdp_current pop
*Let's list the countries and year for which we have missing openc:
list ccode year openc if missing(openc)

*Generate a new variable
generate gdppc = gdp_current^2/pop 

*Delete a mistaken variable
drop gdppc


generate gdppc = gdp_current/pop
replace gdppc = gdppc/1000
generate ln_gdppc = ln(gdppc)




*Standard scatterplot (twoway family)
twoway (scatter openc gdppc) (qfit openc gdppc) if (year==2000 & openc<=200), title(Quadratic fit) legend(lab(1 Openness)) xtitle (GDP per capita)

twoway (scatter openc gdppc) (qfit openc gdppc) if (year==2000 & openc<=200),
title(Quadratic fit) legend(lab(1 Openness)) xtitle (GDP per capita) 

twoway (scatter openc gdppc) (qfit openc gdppc) if (year==2000 & openc<=200), ///
title(Quadratic fit) legend(lab(1 Openness)) xtitle (GDP per capita) 

*One possible alternative
scatter openc gdppc || qfit openc gdppc || if year==2000 & openc<=200,
title(Quadratic fit) legend(lab(1 Openness)) xtitle (GDP per capita)



*Using logGDPpc
twoway (scatter openc ln_gdppc) (qfit openc ln_gdppc) if (year==2000 & openc<=200), 
title(Quadratic fit after log transformation) legend(lab(1 Openness))
xtitle (log GDP per capita)

*Playing with scheme
twoway (scatter openc ln_gdppc) (qfit openc ln_gdppc) if (year==2000 & openc<=200), scheme(economist) ///
title(Quadratic fit after log transformation) legend(lab(1 Openness)) ///
xtitle (log GDP per capita)



twoway (scatter openc gdppc) (lpoly openc gdppc, degree(1) kernel(epan2) bwidth(10000) ) if (year==2000 & openc<=200), ///
	title(Smoother) legend(lab(1 Openness)) xtitle (GDP per capita)
	
*Final attempt (yes!)
twoway (scatter openc gdppc, mlabel(ccode)) (lpoly openc gdppc, degree(1) kernel(epan2) bwidth(10000) ) if (year==2000 & openc<=200), ///
	title(Smoother) legend(lab(1 Openness)) xtitle (GDP per capita)
	

**** SOME MORE MATERIAL ****


*Simple Linear Pearson correlation
corr openc gdppc

*Simple Linear Regression
regress openc gdppc
*Generate predicted values of the dependent variable
predict popenc


*correlation and regression
corr openc gdppc

*standardizing variables
gen s_openc = (openc-69.55744 )/47.23225
egen sss_openc = std(openc)
egen sss_gdppc = std(gdppc)

regress sss_openc sss_gdppc

regress sss_openc sss_gdppc, noconst

 
*A useful way to check if the model is over/under predicting the data
keep if ccode=="ITA"
tsset year
tsline openc popenc
